from setuptools import setup

setup(name='sara_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['sara_distributions'],
      author = 'Sara Jalali',
      author_email = 'sr.jalali@gmail.com',
      zip_safe=False)
